Pants
*****

Pants is a lightweight framework for writing asynchronous network applications
in Python. Pants is simple, fast and very good-looking.

Pants is available under the
`Apache License, Version 2.0 <http://www.apache.org/licenses/LICENSE-2.0.html>`_

Install
=======

Pants can be installed using `pip <http://pypi.python.org/pypi/pip>`_::

    pip install pants

You can also grab the latest code from the `git <http://git-scm.com/>`_
repository::

    git clone git://github.com/ecdavis/pants

Pants requires `Python 2.6+ <http://python.org/>`_ - Python 3 is not yet
supported.

Community
=========

Pants has a small but active community of developers who congregate in the IRC
channel `#pantsmud <http://webchat.freenode.net/?channels=pantsmud>`_ on
irc.freenode.net.

Documentation
=============

.. toctree::
    :maxdepth: 2

    overview
    guides/index
    examples/index
    benchmarks

API
===

.. toctree::
    :maxdepth: 2

    core/index
    utilities/index
    web/index
    contrib/index

